module Types(
    Car(..)
  , Sensor
  , wheelBase
  , phiMax
  , accMax
  , brakeDec
  , frDec
  , carShape
  ) where

import Geometry (Dimension, Angle, Point, add)

-- State of the car.
data Car = Car { w     :: !Angle
	       , pos   :: !Point
               , v     :: !Double
	       } 

-- Sensor input
type Sensor = [(Angle, Maybe Dimension)]


-- Parameters: 

type Velocity= Double

-- Wheel base
wheelBase :: Dimension
wheelBase =  1.8

-- Max. steering angle (60)
phiMax :: Double
phiMax = pi/3

-- Acceleration forward (full throttle :-)
accMax :: Double 
accMax = 10  -- m/s^2

-- Deceleration when braking
brakeDec :: Velocity-> Double
brakeDec v =  - (3* v+ 10) -- m/s^2 

-- Frictional deceleration
frDec :: Velocity-> Double
frDec v = - (0.01* v^2+ 0.2*v)
        

-- Shape of the car, as a polygon (w/o the wheels)
carShape :: [Point]
carShape = 
   map (add (-0.9, 0))
       [(-0.6, 0.4), (2.4, 0.4), (2.6, 0.2),
        (2.6, -0.2), (2.4,-0.4), (-0.6, -0.4)]
